@@ -58,7 +58,7 @@ from .user_agent import User_Agent
 
 # ------------------------------------------------------------------------------- #
 
-__version__ = '1.2.52'
+__version__ = '1.2.56'
 
 # ------------------------------------------------------------------------------- #
 
@@ -199,7 +199,7 @@ class CloudScraper(Session):
         try:
             print(dump.dump_all(req).decode('utf-8'))
         except ValueError as e:
-            print("Debug Error: {}".format(getattr(e, 'message', e)))
+            print(f"Debug Error: {getattr(e, 'message', e)}")
 
     # ------------------------------------------------------------------------------- #
     # Unescape / decode html entities
@@ -225,10 +225,10 @@ class CloudScraper(Session):
                 resp._content = brotli.decompress(resp.content)
             else:
                 logging.warning(
-                    'You\'re running urllib3 {}, Brotli content detected, '
+                    f'You\'re running urllib3 {requests.packages.urllib3.__version__}, Brotli content detected, '
                     'Which requires manual decompression, '
                     'But option allow_brotli is set to False, '
-                    'We will not continue to decompress.'.format(requests.packages.urllib3.__version__)
+                    'We will not continue to decompress.'
                 )
 
         return resp
@@ -290,7 +290,7 @@ class CloudScraper(Session):
                 _ = self._solveDepthCnt
                 self.simpleException(
                     CloudflareLoopProtection,
-                    "!!Loop Protection!! We have tried to solve {} time(s) in a row.".format(_)
+                    f"!!Loop Protection!! We have tried to solve {_} time(s) in a row."
                 )
 
             self._solveDepthCnt += 1
@@ -359,7 +359,7 @@ class CloudScraper(Session):
                     resp.text,
                     re.M | re.S
                 )
-                and re.search(r'window._cf_chl_enter\(', resp.text, re.M | re.S)
+                and re.search(r'window._cf_chl_enter\s*[\(=]', resp.text, re.M | re.S)
             )
         except AttributeError:
             pass
@@ -380,7 +380,7 @@ class CloudScraper(Session):
                     resp.text,
                     re.M | re.S
                 )
-                and re.search(r'window._cf_chl_enter\(', resp.text, re.M | re.S)
+                and re.search(r'\s*id="trk_captcha_js"', resp.text, re.M | re.S)
             )
         except AttributeError:
             pass
@@ -500,17 +500,11 @@ class CloudScraper(Session):
         except Exception as e:
             self.simpleException(
                 CloudflareIUAMError,
-                'Unable to parse Cloudflare anti-bots page: {}'.format(
-                    getattr(e, 'message', e)
-                )
+                f"Unable to parse Cloudflare anti-bots page: {getattr(e, 'message', e)}"
             )
 
         return {
-            'url': '{}://{}{}'.format(
-                hostParsed.scheme,
-                hostParsed.netloc,
-                self.unescape(formPayload['challengeUUID'])
-            ),
+            'url': f"{hostParsed.scheme}://{hostParsed.netloc}{self.unescape(formPayload['challengeUUID'])}",
             'data': payload
         }
 
@@ -591,11 +585,7 @@ class CloudScraper(Session):
         hostParsed = urlparse(url)
 
         return {
-            'url': '{}://{}{}'.format(
-                hostParsed.scheme,
-                hostParsed.netloc,
-                self.unescape(formPayload['challengeUUID'])
-            ),
+            'url': f"{hostParsed.scheme}://{hostParsed.netloc}{self.unescape(formPayload['challengeUUID'])}",
             'data': dataPayload
         }
 
@@ -705,7 +695,7 @@ class CloudScraper(Session):
                 cloudflare_kwargs,
                 'headers',
                 {
-                    'Origin': '{}://{}'.format(urlParsed.scheme, urlParsed.netloc),
+                    'Origin': f'{urlParsed.scheme}://{urlParsed.netloc}',
                     'Referer': resp.url
                 }
             )
@@ -803,7 +793,7 @@ class CloudScraper(Session):
             resp = scraper.get(url, **kwargs)
             resp.raise_for_status()
         except Exception:
-            logging.error('"{}" returned an error. Could not collect tokens.'.format(url))
+            logging.error(f'"{url}" returned an error. Could not collect tokens.')
             raise
 
         domain = urlparse(resp.url).netloc
@@ -811,7 +801,7 @@ class CloudScraper(Session):
         cookie_domain = None
 
         for d in scraper.cookies.list_domains():
-            if d.startswith('.') and d in ('.{}'.format(domain)):
+            if d.startswith('.') and d in (f'.{domain}'):
                 cookie_domain = d
                 break
         else:
@@ -844,11 +834,9 @@ class CloudScraper(Session):
 
 if ssl.OPENSSL_VERSION_INFO < (1, 1, 1):
     print(
-        "DEPRECATION: The OpenSSL being used by this python install ({}) does not meet the minimum supported "
+        f"DEPRECATION: The OpenSSL being used by this python install ({ssl.OPENSSL_VERSION}) does not meet the minimum supported "
         "version (>= OpenSSL 1.1.1) in order to support TLS 1.3 required by Cloudflare, "
-        "You may encounter an unexpected Captcha or cloudflare 1020 blocks.".format(
-            ssl.OPENSSL_VERSION
-        )
+        "You may encounter an unexpected Captcha or cloudflare 1020 blocks."
     )
 
 # ------------------------------------------------------------------------------- #
